/*
OSEPP 4-DIGIT PASSCODE EXAMPLE 
 
 a basic sketch illustrating a three digit passcode authentication. When false values entered, red indicator led blinks.
 if value code (passcode is ' 1 2 3 ' ) is pressed, buzzer and blue light turn on, confirming. 
 Refer to the serial monitor for button pressed feedback. 
 
 BREAKOUT BOARD PINOUTS:
 
 4 digit capacitive touch sensor
 
 OUT1 = PIN 11
 OUT2 = PIN 10
 OUT3 = PIN9
 OUT4 = PIN8
 
 LEDS
 
 RED ERROR LED = PIN 3
 GREEN CORRECT LED = PIN 12
 

 *** note ****
 Check the serial monitor when running sketch. a slight delay is added
 for debugging. You will need to wait a slight moment between presses to
 register button. Can be adjusted. 
 
 
 */

const int NUMBER_PADS[4]  = { 
  11,10,9,8};
int pinCount = 4;
int STORED_DIGITS[2];
const int ERROR_LED = 3;
const int CORRECT_LED = 12;
int button1State = 0;         // variable for reading the pushbutton status
int button2State = 0;         // variable for reading the pushbutton status
int button3State = 0;         // variable for reading the pushbutton status
int button4State = 0;         // variable for reading the pushbutton status
int DIGIT_ELEMENTS = 0; //used to cycle through each press in switch case
int DIM = 20, DELAY = 1000;
int nextTimer, counter;


void setup() {
  Serial.begin(9600);
  // initialize the LED pin as an output:
  pinMode(ERROR_LED, OUTPUT);  
  pinMode(CORRECT_LED, OUTPUT);      
  // initialize the pushbutton pin as an input:
  for (int thisPin = 0; thisPin < pinCount; thisPin++)  {
    pinMode(NUMBER_PADS[thisPin], INPUT);      
  }
}

void loop(){
  // read the state of the push buttons values:

  button1State = digitalRead(NUMBER_PADS[0]);
  button2State = digitalRead(NUMBER_PADS[1]);
  button3State = digitalRead(NUMBER_PADS[2]);
  button4State = digitalRead(NUMBER_PADS[3]);

  switch(DIGIT_ELEMENTS){ //checking for our stored passcode, '1 2 3'

  case 0:
    digitalWrite(ERROR_LED, LOW);

    if(button1State==HIGH){
      Serial.println("1st digit CORRECT");
      STORED_DIGITS[0] = 1; 
      DIGIT_ELEMENTS = 1;

    }
    else if(button2State==HIGH || button3State==HIGH || button4State==HIGH) {
      Serial.println("incorrect 1st digit stored");
      STORED_DIGITS[0] = 0; 
      DIGIT_ELEMENTS = 1;  

    }
    break;


  case 1:
    digitalWrite(ERROR_LED, LOW);

    if(button2State==HIGH ){
      Serial.println("2nd digit CORRECT");
      STORED_DIGITS[1] = 2; 
      DIGIT_ELEMENTS = 2;
    }
    else if(button1State==HIGH || button3State==HIGH || button4State==HIGH) {
      Serial.println("incorrect 2nd digit stored");
      STORED_DIGITS[1] = 0; 
      DIGIT_ELEMENTS = 2;
    }
    break;


  case 2:
    digitalWrite(ERROR_LED, LOW);

    if(button3State==HIGH && STORED_DIGITS[0]==1 && STORED_DIGITS[1]==2){
      Serial.println("3rd digit CORRECT");
      STORED_DIGITS[2] = 3; 
      DIGIT_ELEMENTS = 3;

    }
    else if(button1State==HIGH || button2State==HIGH || button4State==HIGH ) {
      digitalWrite(ERROR_LED, HIGH);
      digitalWrite(CORRECT_LED, LOW);
      Serial.println("ACCESS DENIED. PLEASE RE ENTER PASSCODE");

      STORED_DIGITS[2] = 0; 
      DIGIT_ELEMENTS = 0;


    }

    break;


  case 3:
    digitalWrite(CORRECT_LED, HIGH);

    Serial.println("ACCESS GRANTED");
    digitalWrite(ERROR_LED, LOW);
    analogWrite(BUZZER, 20);


    if (millis() < nextTimer)   return;

    nextTimer = millis() + DELAY;
    ++counter;
    Serial.println(counter);
    if(counter > 1){
      digitalWrite(CORRECT_LED, LOW);
      analogWrite(BUZZER, 0);

      counter = 0;
      DIGIT_ELEMENTS=0;

    }

    break;


  }//end switch case

  delay(500);

}// end program


